@@ -52,7 +52,7 @@ def vol_target_indice_rebalancing(weight_data=None, vol_target = None, volatilit
         value = previous_value * (1 + current_return * volatility_factor)
         current_values = {'Date' : date_index, 'indice': value, 'volatility_factor':volatility_factor}
         target_vol_values_list.append(current_values)
-        # we readjust the volatility factor    
+        # we readjust the volatility factor
         if row['is_rebalancing']:
             volatility_factor = vol_target / weight_data.loc[date_index,'rolling_vol_indice']
         previous_value = value
@@ -87,16 +87,19 @@ def global_drift_weight(previous_weights,current_returns):
             global_drift_weight = global_drift_weight +  previous_weights[key]
     return global_drift_weight
 
-def vol_capped_indice_rebalancing(price_data= None, inception_date=None, risk_budget_allocations = None,capped_weights=None, target_vol = None, initial_value= 100., rebalancing_method = None , volatility_window = 252, early_rebalancing = False, last = True):
+def vol_saturation_indice_rebalancing(price_data= None, inception_date=None, risk_budget_allocations = None, capped_weights=None, target_vol = None, initial_value= 100., rebalancing_method = None, volatility_window = 252, early_rebalancing = False, last = True):
     ### we must be able to assess the historical volatility on the beginning day
     assert inception_date >= min(price_data.index) + timedelta(days=volatility_window)
     assert risk_budget_allocations is not None
     assert capped_weights is not None
     assert target_vol is not None
+    capped_weights = drop_cap_weight_to_key(capped_weights.copy())
+    risk_budget_allocations = drop_budget_risk_to_key(risk_budget_allocations.copy())
 
     constituents = capped_weights.keys()
+    print(constituents)
+    print(price_data.columns)
     assert len([constituent for constituent in constituents if constituent in price_data.columns]) == len(constituents)
-
     #############
     #############
     #############
@@ -174,8 +177,17 @@ def append_weight_to_key(current_weights):
     return translated_weights
 
 
+def drop_cap_weight_to_key(current_weights):
+    translated_weights = {}
+    for key, val in current_weights.items():
+        translated_weights[key.replace('weight_cap_', '')] = val
+    return translated_weights
 
-
+def drop_budget_risk_to_key(current_weights):
+    translated_weights = {}
+    for key, val in current_weights.items():
+        translated_weights[key.replace('budget_risk_', '')] = val
+    return translated_weights
 
 def indice_rebalancing(price_data= None, inception_date=None, target_weights=None, initial_value= 100., rebalancing_method = None , early_rebalancing = False):
     if target_weights is None:
@@ -314,3 +326,4 @@ def to_hedged_euro(weight_data = None, rates_data = None):
 
 
 
+
